==> haskell-lua-arbitrary-1.0.1.1-127.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-lua-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lua-arbitrary
version:              1.0.1.1
visibility:           public
id:                   lua-arbitrary-1.0.1.1-KKuCXfS60IwIoVaZfDNsPU
key:                  lua-arbitrary-1.0.1.1-KKuCXfS60IwIoVaZfDNsPU
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Arbitrary instances for Lua types.
description:
    Provides instances for QuickCheck'\''s \"Arbitrary\"
    typeclass.

category:             Foreign
abi:                  9f63ff0fc042a88a0faeb64ae9e963fe
exposed:              True
exposed-modules:      Lua.Arbitrary
import-dirs:          /usr/lib/ghc-9.6.6/site-local/lua-arbitrary-1.0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lua-arbitrary-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lua-arbitrary-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lua-arbitrary
hs-libraries:         HSlua-arbitrary-1.0.1.1-KKuCXfS60IwIoVaZfDNsPU
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1
    lua-2.3.3-8SYrA1CAYT85bngYHR6FzJ

haddock-interfaces:
    /usr/share/doc/haskell-lua-arbitrary/html/lua-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-lua-arbitrary/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lua-arbitrary-1.0.1.1-128-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-lua-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lua-arbitrary
version:              1.0.1.1
visibility:           public
id:                   lua-arbitrary-1.0.1.1-HdPQa4xv73L5adVXSRuKup
key:                  lua-arbitrary-1.0.1.1-HdPQa4xv73L5adVXSRuKup
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2023 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Arbitrary instances for Lua types.
description:
    Provides instances for QuickCheck'\''s \"Arbitrary\"
    typeclass.

category:             Foreign
abi:                  a6c60481660d44c4dbaf2e4aaf47f808
exposed:              True
exposed-modules:      Lua.Arbitrary
import-dirs:          /usr/lib/ghc-9.6.6/site-local/lua-arbitrary-1.0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lua-arbitrary-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lua-arbitrary-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lua-arbitrary
hs-libraries:         HSlua-arbitrary-1.0.1.1-HdPQa4xv73L5adVXSRuKup
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    lua-2.3.3-DlJXYaKcRYH9BfYMQSRTd9

haddock-interfaces:
    /usr/share/doc/haskell-lua-arbitrary/html/lua-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-lua-arbitrary/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
